Module git_watch

Module git_watch 

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-workspace crate

Git Watch Mode

Monitors a Git repository for OpenAPI spec changes and auto-syncs mocks. This enables contract-driven mocking where mocks stay in sync with API specifications.

Structs

GitWatchConfigDeprecated
Git watch configuration
GitWatchServiceDeprecated
Git watch service that monitors a repository for changes