👎Deprecated:
Will be extracted to mockforge-import crate
Import functionality for MockForge
This module provides functionality to import API definitions from external formats and convert them to MockForge routes, as well as generate commands from OpenAPI specs.
Re-exports
pub use asyncapi_import::import_asyncapi_spec;Deprecated pub use asyncapi_import::AsyncApiImportResult;Deprecated pub use asyncapi_import::AsyncApiSpecInfo;Deprecated pub use asyncapi_import::ChannelOperation;Deprecated pub use asyncapi_import::ChannelProtocol;Deprecated pub use asyncapi_import::MockForgeChannel;Deprecated pub use asyncapi_import::OperationType;Deprecated pub use curl_import::import_curl_commands;Deprecated pub use curl_import::CurlImportResult;Deprecated pub use curl_import::MockForgeResponse as CurlMockForgeResponse;Deprecated pub use curl_import::MockForgeRoute as CurlMockForgeRoute;Deprecated pub use har_import::import_har_archive;Deprecated pub use har_import::HarImportResult;Deprecated pub use har_import::MockForgeResponse as HarMockForgeResponse;Deprecated pub use har_import::MockForgeRoute as HarMockForgeRoute;Deprecated pub use import_utils::detect_format;Deprecated pub use import_utils::FormatDetection;Deprecated pub use import_utils::ImportFormat;Deprecated pub use insomnia_import::import_insomnia_export;Deprecated pub use insomnia_import::InsomniaImportResult;Deprecated pub use insomnia_import::MockForgeResponse as InsomniaMockForgeResponse;Deprecated pub use insomnia_import::MockForgeRoute as InsomniaMockForgeRoute;Deprecated pub use openapi_command_generator::generate_commands_from_openapi;Deprecated pub use openapi_command_generator::CommandFormat;Deprecated pub use openapi_command_generator::CommandGenerationOptions;Deprecated pub use openapi_command_generator::CommandGenerationResult;Deprecated pub use openapi_command_generator::GeneratedCommand;Deprecated pub use openapi_import::import_openapi_spec;Deprecated pub use openapi_import::MockForgeResponse as OpenApiMockForgeResponse;Deprecated pub use openapi_import::MockForgeRoute as OpenApiMockForgeRoute;Deprecated pub use openapi_import::OpenApiImportResult;Deprecated pub use postman_environment::import_postman_environment;Deprecated pub use postman_environment::EnvironmentImportResult;Deprecated pub use postman_environment::EnvironmentVariable;Deprecated pub use postman_environment::VariableSource;Deprecated pub use postman_import::import_postman_collection;Deprecated pub use postman_import::ImportResult;Deprecated pub use postman_import::MockForgeResponse;Deprecated pub use postman_import::MockForgeRoute;Deprecated pub use schema_data_generator::generate_from_schema;Deprecated pub use schema_data_generator::generate_intelligent_response;Deprecated
Modules
- asyncapi_
import Deprecated - AsyncAPI specification import functionality
- curl_
import Deprecated - Curl command import functionality
- har_
import Deprecated - HAR (HTTP Archive) import functionality
- import_
utils Deprecated - Import utilities for detecting and parsing various API formats
- insomnia_
import Deprecated - Insomnia export import functionality
- openapi_
command_ generator Deprecated - OpenAPI command generator
- openapi_
import Deprecated - OpenAPI specification import functionality
- postman_
environment Deprecated - Postman Environment import functionality
- postman_
import Deprecated - Postman collection import functionality
- schema_
data_ generator Deprecated - Schema-based mock data generation