ProxyConfig

Struct ProxyConfig 

pub struct ProxyConfig {
    pub enabled: bool,
    pub target_url: Option<String>,
    pub timeout_seconds: u64,
    pub follow_redirects: bool,
    pub headers: HashMap<String, String>,
    pub prefix: Option<String>,
    pub passthrough_by_default: bool,
    pub rules: Vec<ProxyRule>,
    pub migration_enabled: bool,
    pub migration_groups: HashMap<String, MigrationMode>,
    pub request_replacements: Vec<BodyTransformRule>,
    pub response_replacements: Vec<BodyTransformRule>,
}
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Configuration for proxy behavior

Fields

enabled: bool
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Whether the proxy is enabled

target_url: Option<String>
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Target URL to proxy requests to

timeout_seconds: u64
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Timeout for proxy requests in seconds

follow_redirects: bool
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Whether to follow redirects

headers: HashMap<String, String>
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Additional headers to add to proxied requests

prefix: Option<String>
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Proxy prefix to strip from paths

passthrough_by_default: bool
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Whether to proxy by default

rules: Vec<ProxyRule>
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Proxy rules

migration_enabled: bool
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Whether migration features are enabled

migration_groups: HashMap<String, MigrationMode>
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Group-level migration mode overrides Maps group name to migration mode

request_replacements: Vec<BodyTransformRule>
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Request body replacement rules for browser proxy mode

response_replacements: Vec<BodyTransformRule>
๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Response body replacement rules for browser proxy mode

Implementations

Source

impl ProxyConfig

pub fn new(upstream_url: String) -> Self

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Create a new proxy configuration

pub fn get_effective_migration_mode(&self, path: &str) -> Option<MigrationMode>

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Get the effective migration mode for a path Checks group overrides first, then route-specific mode

pub fn should_proxy(&self, _method: &Method, path: &str) -> bool

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Check if a request should be proxied Respects migration mode: mock forces mock, real forces proxy, shadow forces proxy, auto uses existing logic This is a legacy method that doesnโ€™t evaluate conditions - use should_proxy_with_condition for conditional proxying

pub fn should_proxy_with_condition( &self, method: &Method, uri: &Uri, headers: &HeaderMap, body: Option<&[u8]>, ) -> bool

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Check if a request should be proxied with conditional evaluation This method evaluates conditions in proxy rules using request context

pub fn should_shadow(&self, path: &str) -> bool

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Check if a route should use shadow mode (proxy + generate mock)

pub fn get_upstream_url(&self, path: &str) -> String

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Get the upstream URL for a specific path

pub fn strip_prefix(&self, path: &str) -> String

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Strip the proxy prefix from a path

pub fn update_rule_migration_mode( &mut self, pattern: &str, mode: MigrationMode, ) -> bool

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Update migration mode for a specific route pattern Returns true if the rule was found and updated

pub fn update_group_migration_mode(&mut self, group: &str, mode: MigrationMode)

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Update migration mode for an entire group This affects all routes that belong to the group

pub fn toggle_route_migration(&mut self, pattern: &str) -> Option<MigrationMode>

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Toggle a routeโ€™s migration mode through the stages: mock โ†’ shadow โ†’ real โ†’ mock Returns the new mode if the rule was found

pub fn toggle_group_migration(&mut self, group: &str) -> MigrationMode

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Toggle a groupโ€™s migration mode through the stages: mock โ†’ shadow โ†’ real โ†’ mock Returns the new mode

pub fn get_migration_routes(&self) -> Vec<MigrationRouteInfo>

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Get all routes with their migration status

pub fn get_migration_groups(&self) -> HashMap<String, MigrationGroupInfo>

๐Ÿ‘ŽDeprecated:

Will be extracted to mockforge-proxy crate

Get all migration groups with their status