Time travel and snapshot functionality for saving and restoring system states Time travel and snapshot functionality
This module provides functionality to save and restore entire system states (across protocols, personas, and reality level) with snapshots.
Re-exports
pub use manager::SnapshotManager;pub use state_exporter::BoxedStateExporter;pub use state_exporter::ProtocolStateExporter;pub use types::SnapshotComponents;pub use types::SnapshotManifest;pub use types::SnapshotMetadata;
Modules
- manager
- Snapshot manager for saving and restoring system states
- state_
exporter - Protocol state exporter trait for snapshot functionality
- types
- Snapshot types and data structures